# TeXScythe

A Python library and CLI tool for computing subsets of TeX Live.

Invoke texscyther with --help for more info.

The tlpdb from TeX Live is supplied as an example.

Available on pip/PYPI: https://pypi.python.org/pypi/texscythe/
